AppConstants class

Runtime constants — mirrors Constants.kt

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

baseUrl String
no setter
currencySymbol String
no setter
deviceId String
getter/setter pair
employeeToken String
getter/setter pair
jwtToken String
getter/setter pair
merchantId String
getter/setter pair
outletId String
getter/setter pair
paymentCode String
getter/setter pair
paymentOrderId String
getter/setter pair
transactionUrl String
no setter

Static Methods

isTablet(double shortestSide) bool

Constants

accept → const String
acceptedLanguage → const String
apiKey → const String
apiKeyValue → const String
applicationJson → const String
applicationJsonEncode → const String
appMode → const String
appVersion → const String
authorization → const String
buildNo → const String
contentType → const String
deviceBrand → const String
deviceIdHeader → const String
deviceLocale → const String
deviceOsVersion → const String
deviceType → const String
deviceTypeValue → const String
inventoryUrl → const String
xAuthorization → const String