PreferencesManager class

Mirrors PreferencesManager.kt (DataStore → SharedPreferences)

Constructors

PreferencesManager(SharedPreferences _prefs)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canPrintReceipt() bool
canShowPriceChecker() bool
clearAll() Future<void>
clearEmployeeDetails() Future<void>
getAppMode() AppMode
getAuthToken() Future<String?>
getEmployeeId() int
getEmployeeName() String
getJwtToken() Future<String>
getMerchantId() Future<String>
getMyPaymentQr() String
getOutletId() Future<String>
getShoppingCartId() Future<String>
getXAuthToken() Future<String?>
isDeviceActivated() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveAuthToken(String token) Future<void>
saveCartId(String id) Future<void>
saveEmployeeDetails({required String email, required String dept, required String token, required String pin, required String name, required String position, required String type, required int id, required int status}) Future<void>
saveJwtToken(String token) Future<void>
saveMerchantId(String id) Future<void>
saveOutletId(String id) Future<void>
saveXAuthToken(String token) Future<void>
setAppMode(AppMode mode) Future<void>
setDeviceActivated() Future<void>
setMyPaymentQrPath(String path) Future<void>
setPriceCheckerStatus(bool v) Future<void>
setPrintReceiptStatus(bool v) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited