EmployeeLoginResponse class

Constructors

EmployeeLoginResponse({required bool addProductInfo, required bool allowEzycartLite, required String email, required String employeeDepartment, required String employeeName, required String employeePin, required String employeePosition, required String employeeType, required int id, required int merchantId, required int outletId, required String outletName, required String phoneNum, required int status, required String token})
const
EmployeeLoginResponse.fromJson(Map<String, dynamic> json)
factory

Properties

addProductInfo bool
final
allowEzycartLite bool
final
email String
final
employeeDepartment String
final
employeeName String
final
employeePin String
final
employeePosition String
final
employeeType String
final
hashCode int
The hash code for this object.
no setterinherited
id int
final
merchantId int
final
outletId int
final
outletName String
final
phoneNum String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status int
final
token String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited