CartItem class

Constructors

CartItem({required String barcode, required String reqBarcode, required bool canChangeQty, required bool canRemove, required double discountPrice, required double finalPrice, required bool hasPromo, required int id, required double originalPrice, required String productName, required String promoDescription, required String promoType, required String promotionNo, required int quantity, required double unitPrice, required String uom, required int productWeight, required bool validateWG, required bool isFreshItem, required bool isAlcoholProduct, required bool isInfantMilk, required bool isBakeryProduct, required bool isPrepaid, required bool isIceNeeded, required int noOfItems, required String promoImageUrl, String? imageUrl, required bool applyNormalPromo, required int displayQty, required bool isFreeItem, required bool isMixAndMatchPromo, required bool isSpecialPromoApplied, required double specialPrice, required String specialPromoCode, required String stkNo, required double finalPriceBeforeDiscount, required bool isMemberPrice, required String itemCategory, required String itemCategoryDesc, required bool isTimebasedPromoProduct, required bool applyPromoNow})
const
CartItem.fromJson(Map<String, dynamic> json)
factory

Properties

applyNormalPromo bool
final
applyPromoNow bool
final
barcode String
final
canChangeQty bool
final
canRemove bool
final
discountPrice double
final
displayQty int
final
finalPrice double
final
finalPriceBeforeDiscount double
final
hashCode int
The hash code for this object.
no setterinherited
hasPromo bool
final
id int
final
imageUrl String?
final
isAlcoholProduct bool
final
isBakeryProduct bool
final
isFreeItem bool
final
isFreshItem bool
final
isIceNeeded bool
final
isInfantMilk bool
final
isMemberPrice bool
final
isMixAndMatchPromo bool
final
isPrepaid bool
final
isSpecialPromoApplied bool
final
isTimebasedPromoProduct bool
final
itemCategory String
final
itemCategoryDesc String
final
noOfItems int
final
originalPrice double
final
productName String
final
productWeight int
final
promoDescription String
final
promoImageUrl String
final
promotionNo String
final
promoType String
final
quantity int
final
reqBarcode String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
specialPrice double
final
specialPromoCode String
final
stkNo String
final
unitPrice double
final
uom String
final
validateWG bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited