ProductPriceInfo class

Constructors

ProductPriceInfo({required bool isMemberPrice, required double originalPrice, required double price, required PromoDetails promoDetails, required int noOfItems})
const
ProductPriceInfo.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isMemberPrice bool
final
noOfItems int
final
originalPrice double
final
price double
final
promoDetails PromoDetails
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited