PromoDetails class

Constructors

PromoDetails({bool applyPromoNow = false, String endDate = '', double fixedPrice = 0.0, String imageUrl = '', bool isTimebasedPromoProduct = false, double normalPrice = 0.0, String promoDescription = '', int promotionId = 0, String promotionNo = '', String promotionType = '', int quantity = 0, bool recurring = false, double savingValue = 0.0, double specialPrice = 0.0, String startDate = '', double totalDiscount = 0.0})
const
PromoDetails.fromJson(Map<String, dynamic> json)
factory

Properties

applyPromoNow bool
final
endDate String
final
fixedPrice double
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String
final
isTimebasedPromoProduct bool
final
normalPrice double
final
promoDescription String
final
promotionId int
final
promotionNo String
final
promotionType String
final
quantity int
final
recurring bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
savingValue double
final
specialPrice double
final
startDate String
final
totalDiscount double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited