CreateCartRequest class

Constructors

CreateCartRequest({required String name, required String deviceId, required String merchantId, required String outletId, required String userId, required String trolleyNo, required String appMode, required String employeeId, required String memberNumber})
const

Properties

appMode String
final
deviceId String
final
employeeId String
final
hashCode int
The hash code for this object.
no setterinherited
memberNumber String
final
merchantId String
final
name String
final
outletId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trolleyNo String
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited