CreateCartResponse class

Constructors

CreateCartResponse({required String cartId, required String token, required String currency, required String currencySymbol, required int validationRange, required int validateMaxProduct})
const
CreateCartResponse.fromJson(Map<String, dynamic> json)
factory

Properties

cartId String
final
currency String
final
currencySymbol String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
final
validateMaxProduct int
final
validationRange int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited