ApiService class
Mirrors AuthApi.kt — all active (non-payment) endpoints
Constructors
- ApiService(Dio _dio)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateDevice(
CartActivationRequest request) → Future< NetworkResponse< CartActivationResponse> > -
addProductToCart(
AddProductToCartRequest request) → Future< NetworkResponse< ShoppingCartDetails> > -
createCart(
CreateCartRequest request) → Future< NetworkResponse< CreateCartResponse> > -
deleteProductFromCart(
String cartId, DeleteProductInCartRequest request) → Future< NetworkResponse< ShoppingCartDetails> > -
editProductQuantity(
String cartId, EditProductRequest request) → Future< NetworkResponse< ShoppingCartDetails> > -
employeeLogin(
EmployeeLoginRequest request) → Future< NetworkResponse< EmployeeLoginResponse> > -
getCartDetails(
String cartId) → Future< NetworkResponse< ShoppingCartDetails> > -
getDeviceDetails(
String deviceId) → Future< NetworkResponse< DeviceDetailsResponse> > -
getInvoicePdf(
String referenceNo) → Future< NetworkResponse< InvoiceResponse> > -
getPaymentSummary(
String cartId) → Future< NetworkResponse< ShoppingCartDetails> > -
makePayment(
PaymentRequest request) → Future< NetworkResponse< PaymentResponse> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyPayment(
UpdatePaymentRequest request) → Future< NetworkResponse< PaymentStatusResponse> > -
searchPrice(
String barcode, {required String merchantId, required String outletId}) → Future< NetworkResponse< ProductPriceInfo> > -
searchProduct(
String barcode, {required String merchantId, required String outletId}) → Future< NetworkResponse< ProductInfo> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited