SplashState class

Constructors

SplashState({bool isLoading = true, String? error, bool isSuccess = false, String statusMessage = 'Starting...'})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
isSuccess bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusMessage String
final

Methods

copyWith({bool? isLoading, String? error, bool clearError = false, bool? isSuccess, String? statusMessage}) SplashState
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited