DeviceDetailsResponse class
Constructors
- DeviceDetailsResponse({required String activationKey, required String deviceId, required String deviceStatus, required int merchantId, required int outletId, required String outletCode, required String deviceMode, required String trollyNo})
-
const
-
DeviceDetailsResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activationKey → String
-
final
- deviceId → String
-
final
- deviceMode → String
-
final
- deviceStatus → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- merchantId → int
-
final
- outletCode → String
-
final
- outletId → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- trollyNo → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited