DiscountDetails class
Constructors
- DiscountDetails({required String code, required String discountType, required double discountValue, required String barcode, required String stkNo})
-
const
-
DiscountDetails.fromJson(Map<
String, dynamic> json) -
factory
Properties
- barcode → String
-
final
- code → String
-
final
- discountType → String
-
final
- discountValue → double
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stkNo → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited