ProductInfo class
Constructors
- ProductInfo({required String barcode, required String imageUrl, required bool isFreshItem, required bool isPrepaid, required bool canAddToCart, required String productName, required String skuNumber, required String uom, required bool validateWG, required bool isInfantMilk, required bool isBakeryProduct, required String message})
-
const
-
ProductInfo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- barcode → String
-
final
- canAddToCart → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String
-
final
- isBakeryProduct → bool
-
final
- isFreshItem → bool
-
final
- isInfantMilk → bool
-
final
- isPrepaid → bool
-
final
- message → String
-
final
- productName → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skuNumber → String
-
final
- uom → String
-
final
- validateWG → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited