PaymentResponse class
Constructors
- PaymentResponse({required String orderId, required String qrCode, required String redirectUrl, required String reference, required String referenceNo, required String customerMobileNo, required String customerEmail, required String returnUrl})
-
const
-
PaymentResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- customerEmail → String
-
final
- customerMobileNo → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- orderId → String
-
final
- qrCode → String
-
final
- redirectUrl → String
-
final
- reference → String
-
final
- referenceNo → String
-
final
- returnUrl → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited